==> nextcloud-24.0.5.tgz: nextcloud/apps/viewer/l10n/hu.js <==
OC.L10N.register(
    "viewer",
    {
    "Viewer" : "Megjelenítő",
    "Simple file viewer with slideshow for media" : "Egyszerű fájlmegjelenítő diavetítéssel a médiafájlokhoz",
    "Show your latest holiday photos and videos like in the movies, show a glimpse of your latest novel directly from your nextcloud, choose the best GIF of your collection thanks to the direct preview of your favorites files and many more!" : "Mutassa meg a kedvenc nyaralási fényképeit és videót mint a filmekben, mutassa meg a legfrissebb novellája részletét a Nextcloudban, válassza ki a legjobb GIF-képet a gyűjteményéből a kedvenc fájljainak közvetlen előnézetének, és a számos egyéb funkciónak köszönhetően.",
    "Your browser does not support audio." : "Az Ön böngészője nem támogatja a hangot.",
    "Error loading {name}" : "Hiba a(z) {name} betöltésekor",
    "Unsaved changes" : "Mentetlen változtatások",
    "Drop changes" : "Változtatások elvetése",
    "Your browser does not support videos." : "A böngészője nem támogatja a videókat.",
    "Edit" : "Szerkesztés",
    "Open sidebar" : "Oldalsáv megnyitása",
    "Download" : "Letöltés",
    "Delete" : "Törlés",
    "There is no plugin available to display this file type" : "Nincs elérhető bővítmény a fájltípus megjelenítéséhez",
    "View" : "Megtekintés",
    "Name" : "Név",
    "Save" : "Mentés",
    "Save as" : "Mentés másként",
    "Back" : "Vissza",
    "Loading …" : "Betöltés…",
    "Reset" : "Alaphelyzetbe állítás",
    "All changes will be lost." : "Az összes változtatás elvész.",
    "Are you sure you want to continue?" : "Biztos, hogy folytatja?",
    "Cancel" : "Mégse",
    "Continue" : "Folytatás",
    "Undo" : "Visszavonás",
    "Redo" : "Újra",
    "Show original image" : "Eredeti kép megjelenítése",
    "Zoom in" : "Nagyítás",
    "Zoom out" : "Kicsinyítés",
    "Toggle zoom menu" : "Nagyítási menü be/ki",
    "Adjust" : "Igazítás",
    "Fine-tune" : "Finomhangolás",
    "Filters" : "Szűrők",
    "Watermark" : "Vízjel",
    "Draw" : "Rajzolás",
    "Resize" : "Átméretezés",
    "Invalid image." : "Érvénytelen kép.",
    "Error while uploading the image." : "Hiba történt a kép feltöltése során.",
    "are not images" : "nem képek",
    "is not an image" : "nem kép",
    "to be uploaded" : "feltöltendő",
    "Crop" : "Levágás",
    "Original" : "Eredeti",
    "Custom" : "Egyéni",
    "Square" : "Négyzetes",
    "Landscape" : "Fekvő",
    "Portrait" : "Álló",
    "Ellipse" : "Ellipszis",
    "Classic TV" : "Klasszikus TV",
    "CinemaScope" : "CinemaScope",
    "Arrow" : "Nyíl",
    "Blur" : "Elmosás",
    "Brightness" : "Fényerő",
    "Contrast" : "Kontraszt",
    "Un-flip X" : "X-tengelyre tükrözés visszavonása",
    "Flip X" : "X-tengelyre tükrözés",
    "Un-flip Y" : "Y-tengelyre tükrözés visszavonása",
    "Flip Y" : "Y-tengelyre tükrözés",
    "HSV" : "HSV",
    "Hue" : "Fényerő",
    "Saturation" : "Telítettség",
    "Value" : "Érték",
    "Image" : "Kép",
    "Importing …" : "Importálás…",
    "+ Add image" : "+ Kép hozzáadása",
    "Line" : "Vonal",
    "Pen" : "Toll",
    "Polygon" : "Sokszög",
    "Sides" : "Oldalak",
    "Rectangle" : "Téglalap",
    "Corner Radius" : "Saroklekerekítés sugara",
    "Width in pixels" : "Szélesség képpontokban",
    "Height in pixels" : "Magasság képpontokban",
    "Toggle ratio lock" : "Arányzárolás be/ki",
    "Reset to original image size" : "Visszaállítás az eredeti képméretre",
    "Rotate" : "Forgatás",
    "Text" : "Szöveg",
    "Text spacing" : "Szövegtávolság",
    "Text alignment" : "Szöveg igazítása",
    "Font family" : "Betűkészletcsalád",
    "Size" : "Méret",
    "Letter spacing" : "Betűköz",
    "Line height" : "Sormagasság",
    "Warmth" : "Melegség",
    "+ Add watermark" : "+ Vízjel hozzáadása",
    "Choose watermark type" : "Válasszon vízjeltípust",
    "Upload watermark" : "Vízjel feltöltése",
    "Add as text" : "Hozzáadás szövegként",
    "Padding" : "Helykitöltés",
    "Shadow" : "Árnyék",
    "Horizontal" : "Vízszintes",
    "Vertical" : "Függőleges",
    "Opacity" : "Átlátszatlanság",
    "Position" : "Pozíció",
    "Stroke" : "Körberajzolás",
    "Save image as" : "Kép mentése másként",
    "Extension" : "Kiterjesztés",
    "Name is required." : "A név kötelező.",
    "Quality" : "Minőség",
    "Saved image size (width x height)" : "Mentett kép mérete (szélesség×magasság)",
    "Note that the selected crop area is lower than the applied resize which might cause quality decrease" : "Vegye figyelembe, hogy a kijelölt levágási terület kisebb mint az alkalmazott átméretezés, amely minőségcsökkenést okozhat",
    "Actual size (100%)" : "Tényleges méret (100%)",
    "Fit size" : "Illeszkedő méret"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-24.0.10.tgz: nextcloud/apps/viewer/l10n/hu.js <==
OC.L10N.register(
    "viewer",
    {
    "Viewer" : "Megjelenítő",
    "Simple file viewer with slideshow for media" : "Egyszerű fájlmegjelenítő diavetítéssel a médiafájlokhoz",
    "Show your latest holiday photos and videos like in the movies, show a glimpse of your latest novel directly from your Nextcloud, choose the best GIF of your collection thanks to the direct preview of your favorites files and many more!" : "Mutassa meg a kedvenc nyaralási fényképeit és videót mint a filmekben, mutassa meg a legfrissebb regénye részletét a Nextcloudban, válassza ki a legjobb GIF-képet a gyűjteményéből a kedvenc fájljainak közvetlen előnézetének, és a számos egyéb funkciónak köszönhetően.",
    "Your browser does not support audio." : "Az Ön böngészője nem támogatja a hangot.",
    "Error loading {name}" : "Hiba a(z) {name} betöltésekor",
    "Image saved" : "Kép elmentve",
    "Error saving image" : "Hiba a kép mentése során",
    "Unsaved changes" : "Mentetlen változtatások",
    "Drop changes" : "Változtatások elvetése",
    "Content of \"{fileName}\"" : "A(z) „{fileName}” tartalma",
    "Your browser does not support videos." : "A böngészője nem támogatja a videókat.",
    "Edit" : "Szerkesztés",
    "Open sidebar" : "Oldalsáv megnyitása",
    "Download" : "Letöltés",
    "Delete" : "Törlés",
    "There is no plugin available to display this file type" : "Nincs elérhető bővítmény a fájltípus megjelenítéséhez",
    "View" : "Megtekintés",
    "Name" : "Név",
    "Save" : "Mentés",
    "Save as" : "Mentés másként",
    "Back" : "Vissza",
    "Loading …" : "Betöltés…",
    "Reset" : "Alaphelyzetbe állítás",
    "All changes will be lost." : "Az összes változtatás elvész.",
    "Are you sure you want to continue?" : "Biztos, hogy folytatja?",
    "Cancel" : "Mégse",
    "Continue" : "Folytatás",
    "Undo" : "Visszavonás",
    "Redo" : "Újra",
    "Show original image" : "Eredeti kép megjelenítése",
    "Zoom in" : "Nagyítás",
    "Zoom out" : "Kicsinyítés",
    "Toggle zoom menu" : "Nagyítási menü be/ki",
    "Adjust" : "Igazítás",
    "Fine-tune" : "Finomhangolás",
    "Filters" : "Szűrők",
    "Watermark" : "Vízjel",
    "Draw" : "Rajzolás",
    "Resize" : "Átméretezés",
    "Invalid image." : "Érvénytelen kép.",
    "Error while uploading the image." : "Hiba történt a kép feltöltése során.",
    "are not images" : "nem képek",
    "is not an image" : "nem kép",
    "to be uploaded" : "feltöltendő",
    "Crop" : "Levágás",
    "Original" : "Eredeti",
    "Custom" : "Egyéni",
    "Square" : "Négyzetes",
    "Landscape" : "Fekvő",
    "Portrait" : "Álló",
    "Ellipse" : "Ellipszis",
    "Classic TV" : "Klasszikus TV",
    "CinemaScope" : "CinemaScope",
    "Arrow" : "Nyíl",
    "Blur" : "Elmosás",
    "Brightness" : "Fényerő",
    "Contrast" : "Kontraszt",
    "Un-flip X" : "X-tengelyre tükrözés visszavonása",
    "Flip X" : "X-tengelyre tükrözés",
    "Un-flip Y" : "Y-tengelyre tükrözés visszavonása",
    "Flip Y" : "Y-tengelyre tükrözés",
    "HSV" : "HSV",
    "Hue" : "Fényerő",
    "Saturation" : "Telítettség",
    "Value" : "Érték",
    "Image" : "Kép",
    "Importing …" : "Importálás…",
    "+ Add image" : "+ Kép hozzáadása",
    "Line" : "Vonal",
    "Pen" : "Toll",
    "Polygon" : "Sokszög",
    "Sides" : "Oldalak",
    "Rectangle" : "Téglalap",
    "Corner Radius" : "Saroklekerekítés sugara",
    "Width in pixels" : "Szélesség képpontokban",
    "Height in pixels" : "Magasság képpontokban",
    "Toggle ratio lock" : "Arányzárolás be/ki",
    "Reset to original image size" : "Visszaállítás az eredeti képméretre",
    "Rotate" : "Forgatás",
    "Text" : "Szöveg",
    "Text spacing" : "Szövegtávolság",
    "Text alignment" : "Szöveg igazítása",
    "Font family" : "Betűkészletcsalád",
    "Size" : "Méret",
    "Letter spacing" : "Betűköz",
    "Line height" : "Sormagasság",
    "Warmth" : "Melegség",
    "+ Add watermark" : "+ Vízjel hozzáadása",
    "Choose watermark type" : "Válasszon vízjeltípust",
    "Upload watermark" : "Vízjel feltöltése",
    "Add as text" : "Hozzáadás szövegként",
    "Padding" : "Helykitöltés",
    "Shadow" : "Árnyék",
    "Horizontal" : "Vízszintes",
    "Vertical" : "Függőleges",
    "Opacity" : "Átlátszatlanság",
    "Position" : "Pozíció",
    "Stroke" : "Körberajzolás",
    "Save image as" : "Kép mentése másként",
    "Extension" : "Kiterjesztés",
    "Name is required." : "A név kötelező.",
    "Quality" : "Minőség",
    "Saved image size (width x height)" : "Mentett kép mérete (szélesség×magasság)",
    "Note that the selected crop area is lower than the applied resize which might cause quality decrease" : "Vegye figyelembe, hogy a kijelölt levágási terület kisebb mint az alkalmazott átméretezés, amely minőségcsökkenést okozhat",
    "Actual size (100%)" : "Tényleges méret (100%)",
    "Fit size" : "Illeszkedő méret",
    "Show your latest holiday photos and videos like in the movies, show a glimpse of your latest novel directly from your nextcloud, choose the best GIF of your collection thanks to the direct preview of your favorites files and many more!" : "Mutassa meg a kedvenc nyaralási fényképeit és videót mint a filmekben, mutassa meg a legfrissebb novellája részletét a Nextcloudban, válassza ki a legjobb GIF-képet a gyűjteményéből a kedvenc fájljainak közvetlen előnézetének, és a számos egyéb funkciónak köszönhetően."
},
"nplurals=2; plural=(n != 1);");
